==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'You will remove all signatures of this petition. Are you sure you want to continue?',
	'aucune_signature' => 'No signature',

	// B
	'bouton_checkbox_envoi_message' => 'possibility to send a message',
	'bouton_checkbox_indiquer_site' => 'must enter the name of a Web site',
	'bouton_checkbox_signature_unique_email' => 'only one signature per email',
	'bouton_checkbox_signature_unique_site' => 'only one signature per website',

	// F
	'filtre' => 'Filter:',
	'form_pet_adresse_site' => 'URL of your site',
	'form_pet_aucune_signature' => 'No signature matching this code...',
	'form_pet_confirmation' => 'Please confirm your signature:',
	'form_pet_deja_signe' => 'You have already signed this text.',
	'form_pet_envoi_mail_confirmation' => 'A confirmation email has just been sent to  @email@. You should visit the URL given in this email to validate your signature.',
	'form_pet_mail_confirmation' => 'Hello,

You asked to sign the petition:
@titre@.

You provided the following information:
    Name: @nom_email@
    Site: @nom_site@ - @url_site@
@message@

IMPORTANT...
To validate your signature, you just need to connect to
the address below (otherwise your request
will be rejected):
    @url@

Thank you for participating!
',
	'form_pet_message_commentaire' => 'A message, a comment?',
	'form_pet_nom_site2' => 'Name of your website',
	'form_pet_probleme_liens' => 'Please edit your message, removing all hyperlinks.',
	'form_pet_probleme_technique' => 'Technical problem: signatures are interrupted momentarily.',
	'form_pet_signature_validee' => 'Your signature is valid. Thank you!',
	'form_pet_site_deja_enregistre' => 'This site is already registered',
	'form_pet_url_invalide' => 'The URL that you entered is not valid.',
	'form_pet_votre_email' => 'Your email address',
	'form_pet_votre_nom' => 'Your name',
	'form_pet_votre_site' => 'If you have a website, you can enter the URL below',

	// I
	'icone_relancer_signataire' => 'Contact the signatory again',
	'icone_relancer_signataires' => 'Contact the signatories again',
	'icone_suivi_petitions' => 'Follow/manage the petitions',
	'icone_supprimer_signature' => 'Delete this signature',
	'icone_supprimer_signatures' => 'Delete the signatures',
	'icone_valider_signature' => 'Confirm this signature',
	'icone_valider_signatures' => 'Confirm the signatures',
	'info_adresse_email' => 'EMAIL:',
	'info_fonctionnement_petition' => 'Petition configuration:',
	'info_signature_supprimee' => 'Signature deleted',
	'info_signature_supprimee_erreur' => 'Error: this deletion code does not correspond to any signatures',
	'info_site_web' => 'WEBSITE:',
	'info_texte_message' => 'Text of your message:',

	// L
	'lien_reponse_article' => 'Comment on this article',

	// N
	'nombre_signatures' => '@nb@ signatures',

	// S
	'sans_nom' => 'Anonymous',
	'signatures_article' => 'Signatures of the article:',
	'signatures_aucune' => 'None',
	'signatures_meme_auteur' => 'Signatures of the same author',
	'signatures_meme_site' => 'Signatures with the same website',
	'signatures_poubelle' => 'Deleted',
	'signatures_prop' => 'Waiting',
	'signatures_publie' => 'Confirmed',
	'signatures_recherche_label' => 'Search for signatures:',
	'signatures_selection' => 'Select the signatures:',
	'signatures_toutes' => 'All',
	'statut_poubelle' => 'Deleted',
	'statut_prop' => 'Awaiting validation',
	'statut_publie' => 'Confirmed',

	// T
	'texte_descriptif_petition' => 'Description of the petition',
	'titre_page_controle_petition' => 'Tracking of the petitions',
	'titre_petition' => 'Petition',
	'titre_petitions' => 'Petitions',
	'titre_selection_action' => 'Selection',
	'titre_signatures_attente' => 'Signatures awaiting validation',
	'titre_signatures_publie' => 'Confirmed signatures',
	'titre_suivi_petition' => 'Tracking of petitions',
	'tout_voir' => 'Show all signatures',

	// U
	'une_signature' => '1 signature',

	// V
	'voir_signatures_objet' => 'Show signatures'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'You will remove all signatures of this petition. Are you sure you want to continue?',
	'aucune_signature' => 'No signature',

	// B
	'bouton_checkbox_envoi_message' => 'possibility to send a message',
	'bouton_checkbox_indiquer_site' => 'must enter the name of a Web site',
	'bouton_checkbox_signature_unique_email' => 'only one signature per email',
	'bouton_checkbox_signature_unique_site' => 'only one signature per website',
	'bouton_radio_activer_petition' => 'Activate the petition',
	'bouton_radio_pas_petition' => 'No petition',
	'bouton_radio_petition_activee' => 'Petition activated',
	'bouton_radio_supprimer_petition' => 'Delete the petition',

	// F
	'filtre' => 'Filter:',
	'form_pet_adresse_site' => 'URL of your site',
	'form_pet_aucune_signature' => 'No signature matching this code...',
	'form_pet_confirmation' => 'Please confirm your signature:',
	'form_pet_deja_signe' => 'You have already signed this text.',
	'form_pet_envoi_mail_confirmation' => 'A confirmation email has just been sent to  @email@. You should visit the URL given in this email to validate your signature.',
	'form_pet_mail_confirmation' => 'Hello,

You asked to sign the petition:
@titre@.

You provided the following information:
    Name: @nom_email@
    Site: @nom_site@ - @url_site@
@message@

IMPORTANT...
To validate your signature, you just need to connect to
the address below (otherwise your request
will be rejected):
    @url@

Thank you for participating!
',
	'form_pet_message_commentaire' => 'A message, a comment?',
	'form_pet_nom_site2' => 'Name of your website',
	'form_pet_probleme_liens' => 'Please edit your message, removing all hyperlinks.',
	'form_pet_probleme_technique' => 'Technical problem: signatures are interrupted momentarily.',
	'form_pet_signature_validee' => 'Your signature is valid. Thank you!',
	'form_pet_site_deja_enregistre' => 'This site is already registered',
	'form_pet_url_invalide' => 'The URL that you entered is not valid.',
	'form_pet_votre_email' => 'Your email address',
	'form_pet_votre_nom' => 'Your name',
	'form_pet_votre_site' => 'If you have a website, you can enter the URL below',

	// I
	'icone_relancer_signataire' => 'Contact the signatory again',
	'icone_relancer_signataires' => 'Contact the signatories again',
	'icone_suivi_petitions' => 'Follow/manage the petitions',
	'icone_supprimer_signature' => 'Delete this signature',
	'icone_supprimer_signatures' => 'Delete the signatures',
	'icone_valider_signature' => 'Confirm this signature',
	'icone_valider_signatures' => 'Confirm the signatures',
	'info_adresse_email' => 'EMAIL:',
	'info_fonctionnement_petition' => 'Petition configuration:',
	'info_signature_supprimee' => 'Signature deleted',
	'info_signature_supprimee_erreur' => 'Error: this deletion code does not correspond to any signatures',
	'info_site_web' => 'WEBSITE:',
	'info_texte_message' => 'Text of your message:',

	// L
	'lien_reponse_article' => 'Comment on this article',

	// N
	'nombre_signatures' => '@nb@ signatures',

	// S
	'sans_nom' => 'Anonymous',
	'signatures_article' => 'Signatures of the article:',
	'signatures_aucune' => 'None',
	'signatures_meme_auteur' => 'Signatures of the same author',
	'signatures_meme_site' => 'Signatures with the same website',
	'signatures_poubelle' => 'Deleted',
	'signatures_prop' => 'Waiting',
	'signatures_publie' => 'Confirmed',
	'signatures_recherche_label' => 'Search for signatures:',
	'signatures_selection' => 'Select the signatures:',
	'signatures_toutes' => 'All',
	'statut_poubelle' => 'Deleted',
	'statut_prop' => 'Awaiting validation',
	'statut_publie' => 'Confirmed',

	// T
	'texte_descriptif_petition' => 'Description of the petition',
	'titre_page_controle_petition' => 'Tracking of the petitions',
	'titre_petition' => 'Petition',
	'titre_petitions' => 'Petitions',
	'titre_selection_action' => 'Selection',
	'titre_signatures_attente' => 'Signatures awaiting validation',
	'titre_signatures_publie' => 'Confirmed signatures',
	'titre_suivi_petition' => 'Tracking of petitions',
	'tout_voir' => 'Show all signatures',

	// U
	'une_signature' => '1 signature',

	// V
	'voir_signatures_objet' => 'Show signatures'
);

?>
